==> uke-admin-web-scaffold-1.2.1.tgz: package/nav-menu/nav-menu.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
/* eslint-disable no-nested-ternary */
/* eslint-disable no-prototype-builtins */
import React, { Component } from 'react';
import Storage from 'basic-helper/storage';
import { DebounceClass, Call } from 'basic-helper';
import { ToolTip, Icon, PureIcon } from '../ui-refs';
import { storageHelper } from '../config';
import { Link } from '../router-multiple';
import SearchBox from './search';
var delayExec = new DebounceClass();
var MENU_ACTIVE_STORAGE = 'MENU_ACTIVE_STORAGE';
function getScreenHeight() {
    return document.documentElement.clientHeight;
}
function getElementLeft(element) {
    if (!element)
        return null;
    var actualLeft = element.offsetLeft;
    var current = element.offsetParent;
    while (current !== null) {
        actualLeft += (current.offsetLeft + current.clientLeft);
        current = current.offsetParent;
    }
    return actualLeft;
}
function getElementTop(element) {
    if (!element)
        return null;
    var actualTop = element.offsetTop;
    var current = element.offsetParent;
    while (current !== null) {
        actualTop += (current.offsetTop + current.clientTop);
        current = current.offsetParent;
    }
    return actualTop;
}
var iconComFilter = function (_a, props, other) {
    var icon = _a.icon, pureIcon = _a.pureIcon;
    if (!icon && !pureIcon)
        return other;
    var I = pureIcon ? PureIcon : Icon;
    return React.createElement(I, __assign({}, props, { n: pureIcon || icon }));
};
var MENU_CODE_MAPPER = 'MENU_CODE_MAPPER';
var menuCodeMapper = storageHelper.get(MENU_CODE_MAPPER, true) || {};
var MenuItem = function (props) {
    var _a = props.icon, icon = _a === void 0 ? 'bars' : _a, pureIcon = props.pureIcon, title = props.title, $T = props.$T;
    return (React.createElement("div", { className: "layout a-i-c" },
        iconComFilter({ icon: icon, pureIcon: pureIcon }, { classNames: ['item-icon mr10'] }),
        React.createElement("span", null, $T(title)),
        React.createElement("span", { className: "flex" }),
        React.createElement(Icon, { n: "angle-right", classNames: ['direct'] })));
};
/**
 * 左菜单控件
 * 支持无限嵌套结构，支持“树”模式，支持“悬浮”模式
 * menuData 结构
 * {
 *   title: '',
 *   code: '',
 *   icon: '',
 *   child: [
 *     // 递归此结构, 避免和 react 的 children 冲突，故为 child
 *     {
 *       title: '',
 *       code: '',
 *       icon: '',
 *       child: []
 *     }
 *   ]
 * }
 */
var NavMenu = /** @class */ (function (_super) {
    __extends(NavMenu, _super);
    function NavMenu(props) {
        var _this = _super.call(this, props) || this;
        _this.flowModeKey = 'IS_FLOW_MODA';
        _this.getNormalMenuChildren = function (initDataList) {
            if (!initDataList || !Array.isArray(initDataList))
                return;
            // if(!initDataList || !Array.isArray(initDataList)) return console.error(initDataList, 'initDataList 参数错误');
            var _a = _this.props, onClickMenu = _a.onClickMenu, $T = _a.$T;
            var _b = _this.state, showMenuMapper = _b.showMenuMapper, flowMode = _b.flowMode;
            var allSet = [];
            var foldIdx = 0;
            var recursive = function (dataList) {
                var currDOMSets = [];
                dataList.forEach(function (item, currItemIdx) {
                    if (!item)
                        return;
                    var _item = _this.menuItemFilter(item);
                    var child = _item.child, title = _item.title, code = _item.code;
                    var key = code + title;
                    var to = _this.wrapLink(_item);
                    var hasChildren = child && child.length > 0;
                    var isFold = !code || hasChildren;
                    var currFoldIdx = foldIdx;
                    ++foldIdx;
                    var isActive = showMenuMapper.hasOwnProperty(currFoldIdx);
                    var dom;
                    if (isFold) {
                        var childDOM = void 0;
                        if (hasChildren) {
                            childDOM = recursive.call(_this, child);
                        }
                        dom = (React.createElement("div", { key: foldIdx, className: "fold fold-" + currFoldIdx + (flowMode ? '' : (isActive ? ' active' : ' hide-fold')) },
                            React.createElement("div", { className: "fold-title", onClick: function (e) {
                                    !flowMode && _this.toggleFold(e, currFoldIdx);
                                } },
                                React.createElement(MenuItem, __assign({}, _item, { "$T": $T }))),
                            React.createElement("div", { className: "children" }, childDOM)));
                    }
                    else {
                        dom = _this.getMenuLinkerDOM(__assign(__assign({}, _item), { key: key,
                            to: to, onClick: onClickMenu, menuText: title }));
                    }
                    currDOMSets.push(dom);
                });
                return currDOMSets;
            };
            allSet = recursive.call(_this, initDataList);
            return allSet;
        };
        _this.hideFlowMenu = function () {
            delayExec.exec(function () {
                _this.setFlowMenu({
                    isShow: false
                });
            }, 200);
        };
        _this.getMenuLinkerDOM = function (options) {
            var code = options.code, key = options.key, to = options.to, onClick = options.onClick, menuText = options.menuText, icon = options.icon, pureIcon = options.pureIcon;
            var $T = _this.props.$T;
            menuCodeMapper[code] = menuText;
            storageHelper.set(MENU_CODE_MAPPER, menuCodeMapper, true);
            return (React.createElement(Link, { key: key, className: "menu", to: to, onClick: function () { return Call(onClick, key, code); } },
                iconComFilter(options, { classNames: ['mr10'] }, (React.createElement("span", { className: "menu-tip" }, "-"))),
                $T(menuText)));
        };
        _this.getFlowModeDOM = function (initDataList) {
            var flowMenuConfig = _this.state.flowMenuConfig;
            var _a = _this.props, $T = _a.$T, onClickMenu = _a.onClickMenu;
            var offset = flowMenuConfig.offset, _b = flowMenuConfig.activeItem, activeItem = _b === void 0 ? {} : _b, activeIdx = flowMenuConfig.activeIdx, isShow = flowMenuConfig.isShow;
            var flowMenuDOM = (React.createElement("div", { className: "flow-menu-container" + (isShow ? ' show' : ''), onMouseEnter: function () { return delayExec.cancel(); }, onMouseLeave: function () { return _this.hideFlowMenu(); }, style: {
                    left: offset.left
                }, ref: function (flowMenuContainer) {
                    if (flowMenuContainer) {
                        _this.flowMenuContainer = flowMenuContainer;
                        var flowContainerHeight = flowMenuContainer.offsetHeight;
                        var flowContainerScrollTop = _this.navMenuDOM ? _this.navMenuDOM.scrollTop : 0;
                        var expectedOffsetTop = offset.top - flowContainerScrollTop;
                        var parentHeight = offset.height;
                        var offsetBottom = expectedOffsetTop + flowContainerHeight;
                        var overBottom = getScreenHeight() - offsetBottom;
                        var finalOffsetTop = expectedOffsetTop;
                        var flowMenuOffsetTopPx = parentHeight == flowContainerHeight ? 0 : parentHeight;
                        if (overBottom < 0) {
                            /**
                             * 如果高度超过了底部
                             */
                            finalOffsetTop = expectedOffsetTop + overBottom;
                        }
                        flowMenuContainer.style.top = finalOffsetTop - flowMenuOffsetTopPx + "px";
                    }
                } }, _this.getNormalMenuChildren(activeItem.child)));
            var allSet = initDataList.map(function (item, idx) {
                if (!item)
                    return null;
                var _item = _this.menuItemFilter(item);
                var child = _item.child, title = _item.title, code = _item.code;
                var to = _this.wrapLink(_item);
                var isFold = !code || (child && child.length > 0);
                var key = code + title;
                var isHovering = activeIdx == idx;
                return isFold ? (React.createElement("div", { key: idx, onMouseEnter: function (e) {
                        delayExec.cancel();
                        var target = e.target;
                        if (e.currentTarget !== target)
                            return;
                        _this.setFlowMenu({
                            targetElem: target,
                            activeItem: _item,
                            idx: idx
                        });
                    }, onMouseLeave: function () {
                        _this.hideFlowMenu();
                    }, className: "fold" + (isHovering ? ' hover' : '') },
                    React.createElement(MenuItem, __assign({}, _item, { "$T": $T })))) : (_this.getMenuLinkerDOM(__assign(__assign({}, _item), { key: key,
                    to: to, onClick: onClickMenu, menuText: title })));
            });
            return (React.createElement("div", { className: "nav-menu-tree" },
                allSet,
                flowMenuDOM));
        };
        _this.menuItemFilter = function (item) {
            var menuMappers = _this.props.menuMappers;
            var child = menuMappers.child, code = menuMappers.code, title = menuMappers.title, _a = menuMappers.icon, icon = _a === void 0 ? '' : _a;
            return __assign(__assign({}, item), { child: item[child], code: item[code], title: item[title], icon: item[icon] });
        };
        _this.showSearch = function () {
        };
        _this.wrapLink = function (_a) {
            var path = _a.path, code = _a.code;
            return path ? code + "?" + path : code;
        };
        _this.changeMenuUIMode = function (isFlowMode) {
            _this.setState({
                flowMode: isFlowMode
            });
            storageHelper.set(_this.flowModeKey, isFlowMode ? '1' : '0');
        };
        _this.toggleFold = function (e, idx, isShow) {
            e.stopPropagation();
            var showMenuMapper = _this.state.showMenuMapper;
            var nextState = Object.assign({}, showMenuMapper);
            if (typeof isShow != 'undefined') {
                isShow ? (nextState[idx] = true) : delete nextState[idx];
            }
            else if (nextState.hasOwnProperty(idx)) {
                delete nextState[idx];
            }
            else {
                nextState[idx] = true;
            }
            Storage.setItem(MENU_ACTIVE_STORAGE, JSON.stringify(nextState));
            _this.setState({
                showMenuMapper: nextState
            });
        };
        _this.setFlowMenu = function (options) {
            var flowMenuConfig = _this.state.flowMenuConfig;
            var targetElem = options.targetElem, activeItem = options.activeItem, _a = options.isShow, isShow = _a === void 0 ? true : _a, idx = options.idx;
            var nextOffset = flowMenuConfig.offset;
            if (targetElem) {
                var offsetWidth = targetElem.offsetWidth, offsetHeight = targetElem.offsetHeight;
                nextOffset = {
                    top: getElementTop(targetElem),
                    left: getElementLeft(targetElem) + offsetWidth,
                    height: offsetHeight
                };
            }
            _this.setState({
                flowMenuConfig: {
                    offset: nextOffset,
                    activeIdx: idx,
                    activeItem: activeItem,
                    isShow: isShow
                }
            });
        };
        var showMenuMapper = Storage.getItem(MENU_ACTIVE_STORAGE) || '';
        try {
            showMenuMapper = JSON.parse(showMenuMapper);
        }
        catch (e) {
            showMenuMapper = {};
        }
        var storageMode = storageHelper.get(_this.flowModeKey);
        var _a = props.defaultFlowMode, defaultFlowMode = _a === void 0 ? false : _a, menuData = props.menuData;
        window.MENU_DATA = menuData;
        _this.state = {
            showMenuMapper: showMenuMapper,
            flowMenuConfig: {
                activeItem: {},
                activeIdx: '',
                isShow: false,
                offset: {
                    top: 0,
                    left: 0
                }
            },
            flowMode: storageMode ? (!!+storageMode) : defaultFlowMode
        };
        return _this;
    }
    NavMenu.prototype.componentDidMount = function () {
        Call(this.props.onDidMount, menuCodeMapper);
    };
    NavMenu.prototype.render = function () {
        var _this = this;
        var _a = this.props, menuData = _a.menuData, onClickMenu = _a.onClickMenu, onToggleNav = _a.onToggleNav, _b = _a.title, title = _b === void 0 ? 'UKE-Dashboard' : _b, 
        // username,
        // logout,
        $T = _a.$T, show = _a.show;
        var flowMode = this.state.flowMode;
        var menuTree = flowMode ? (this.getFlowModeDOM(menuData)) : (React.createElement("div", { className: "nav-menu-tree" }, this.getNormalMenuChildren(menuData)));
        var renderRes = (React.createElement("div", { className: "nav-menu-wrapper " + (show ? 'show' : 'collapse') },
            React.createElement("div", { ref: function (navMenuDOM) {
                    if (navMenuDOM)
                        _this.navMenuDOM = navMenuDOM;
                }, className: "nav-menu-response " + (flowMode ? 'flow-mode ' : 'tree-mode ') },
                React.createElement("div", { className: "menu-header" },
                    React.createElement("h4", { className: "title" }, title),
                    React.createElement("hr", null),
                    React.createElement("div", { className: "action-group" },
                        React.createElement(SearchBox, { ref: function (e) { _this._seatchBox = e; }, "$T": $T, onClickMenu: onClickMenu, onToggleNav: onToggleNav, codeMapper: menuCodeMapper, showMenu: show }),
                        React.createElement(ToolTip, { position: "bottom", title: $T('切换到') + $T(!flowMode ? '悬浮' : '传统') + $T('模式'), classNames: ['_action-btn'], className: "p10", onClick: function () { return _this.changeMenuUIMode(!flowMode); }, n: flowMode ? "bars" : "bolt" }),
                        React.createElement("span", { className: "flex" }),
                        React.createElement(ToolTip, { onClick: function () { return onToggleNav(!show); }, title: "" + $T(show ? "收起" : "展开") + $T('菜单') + "\uFF08" + $T('快捷键') + "\uFF1Aalt + alt\uFF09'", n: !show ? "greater-than" : "less-than" }))),
                menuTree)));
        return renderRes;
    };
    return NavMenu;
}(Component));
export default NavMenu;

==> uke-admin-web-scaffold-1.2.3.tgz: package/nav-menu/nav-menu.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
/* eslint-disable no-nested-ternary */
/* eslint-disable no-prototype-builtins */
import React, { Component } from 'react';
import Storage from 'basic-helper/storage';
import { DebounceClass, Call } from 'basic-helper';
import { ToolTip, Icon, PureIcon } from '../ui-refs';
import { storageHelper } from '../config';
import { Link } from '../router-multiple';
import SearchBox from './search';
var delayExec = new DebounceClass();
var MENU_ACTIVE_STORAGE = 'MENU_ACTIVE_STORAGE';
function getScreenHeight() {
    return document.documentElement.clientHeight;
}
function getElementLeft(element) {
    if (!element)
        return null;
    var actualLeft = element.offsetLeft;
    var current = element.offsetParent;
    while (current !== null) {
        actualLeft += (current.offsetLeft + current.clientLeft);
        current = current.offsetParent;
    }
    return actualLeft;
}
function getElementTop(element) {
    if (!element)
        return null;
    var actualTop = element.offsetTop;
    var current = element.offsetParent;
    while (current !== null) {
        actualTop += (current.offsetTop + current.clientTop);
        current = current.offsetParent;
    }
    return actualTop;
}
var iconComFilter = function (_a, props, other) {
    var icon = _a.icon, pureIcon = _a.pureIcon;
    if (!icon && !pureIcon)
        return other;
    var I = pureIcon ? PureIcon : Icon;
    return React.createElement(I, __assign({}, props, { n: pureIcon || icon }));
};
var MENU_CODE_MAPPER = 'MENU_CODE_MAPPER';
var menuCodeMapper = storageHelper.get(MENU_CODE_MAPPER, true) || {};
var MenuItem = function (props) {
    var _a = props.icon, icon = _a === void 0 ? 'bars' : _a, pureIcon = props.pureIcon, title = props.title, $T = props.$T;
    return (React.createElement("div", { className: "layout a-i-c" },
        iconComFilter({ icon: icon, pureIcon: pureIcon }, { classNames: ['item-icon mr10'] }),
        React.createElement("span", null, $T(title)),
        React.createElement("span", { className: "flex" }),
        React.createElement(Icon, { n: "angle-right", classNames: ['direct'] })));
};
/**
 * 左菜单控件
 * 支持无限嵌套结构，支持“树”模式，支持“悬浮”模式
 * menuData 结构
 * {
 *   title: '',
 *   code: '',
 *   icon: '',
 *   child: [
 *     // 递归此结构, 避免和 react 的 children 冲突，故为 child
 *     {
 *       title: '',
 *       code: '',
 *       icon: '',
 *       child: []
 *     }
 *   ]
 * }
 */
var NavMenu = /** @class */ (function (_super) {
    __extends(NavMenu, _super);
    function NavMenu(props) {
        var _this = _super.call(this, props) || this;
        _this.flowModeKey = 'IS_FLOW_MODA';
        _this.getNormalMenuChildren = function (initDataList) {
            if (!initDataList || !Array.isArray(initDataList))
                return;
            // if(!initDataList || !Array.isArray(initDataList)) return console.error(initDataList, 'initDataList 参数错误');
            var _a = _this.props, onClickMenu = _a.onClickMenu, $T = _a.$T;
            var _b = _this.state, showMenuMapper = _b.showMenuMapper, flowMode = _b.flowMode;
            var allSet = [];
            var foldIdx = 0;
            var recursive = function (dataList) {
                var currDOMSets = [];
                dataList.forEach(function (item, currItemIdx) {
                    if (!item)
                        return;
                    var _item = _this.menuItemFilter(item);
                    var child = _item.child, title = _item.title, code = _item.code;
                    var key = code + title;
                    var to = _this.wrapLink(_item);
                    var hasChildren = child && child.length > 0;
                    var isFold = !code || hasChildren;
                    var currFoldIdx = foldIdx;
                    ++foldIdx;
                    var isActive = showMenuMapper.hasOwnProperty(currFoldIdx);
                    var dom;
                    if (isFold) {
                        var childDOM = void 0;
                        if (hasChildren) {
                            childDOM = recursive.call(_this, child);
                        }
                        dom = (React.createElement("div", { key: foldIdx, className: "fold fold-" + currFoldIdx + (flowMode ? '' : (isActive ? ' active' : ' hide-fold')) },
                            React.createElement("div", { className: "fold-title", onClick: function (e) {
                                    !flowMode && _this.toggleFold(e, currFoldIdx);
                                } },
                                React.createElement(MenuItem, __assign({}, _item, { "$T": $T }))),
                            React.createElement("div", { className: "children" }, childDOM)));
                    }
                    else {
                        dom = _this.getMenuLinkerDOM(__assign(__assign({}, _item), { key: key,
                            to: to, onClick: onClickMenu, menuText: title }));
                    }
                    currDOMSets.push(dom);
                });
                return currDOMSets;
            };
            allSet = recursive.call(_this, initDataList);
            return allSet;
        };
        _this.hideFlowMenu = function () {
            delayExec.exec(function () {
                _this.setFlowMenu({
                    isShow: false
                });
            }, 200);
        };
        _this.getMenuLinkerDOM = function (options) {
            var code = options.code, key = options.key, to = options.to, onClick = options.onClick, menuText = options.menuText, icon = options.icon, pureIcon = options.pureIcon;
            var $T = _this.props.$T;
            menuCodeMapper[code] = menuText;
            storageHelper.set(MENU_CODE_MAPPER, menuCodeMapper, true);
            return (React.createElement(Link, { key: key, className: "menu", to: to, onClick: function () { return Call(onClick, key, code); } },
                iconComFilter(options, { classNames: ['mr10'] }, (React.createElement("span", { className: "menu-tip" }, "-"))),
                $T(menuText)));
        };
        _this.getFlowModeDOM = function (initDataList) {
            var flowMenuConfig = _this.state.flowMenuConfig;
            var _a = _this.props, $T = _a.$T, onClickMenu = _a.onClickMenu;
            var offset = flowMenuConfig.offset, _b = flowMenuConfig.activeItem, activeItem = _b === void 0 ? {} : _b, activeIdx = flowMenuConfig.activeIdx, isShow = flowMenuConfig.isShow;
            var flowMenuDOM = (React.createElement("div", { className: "flow-menu-container" + (isShow ? ' show' : ''), onMouseEnter: function () { return delayExec.cancel(); }, onMouseLeave: function () { return _this.hideFlowMenu(); }, style: {
                    left: offset.left
                }, ref: function (flowMenuContainer) {
                    if (flowMenuContainer) {
                        _this.flowMenuContainer = flowMenuContainer;
                        var flowContainerHeight = flowMenuContainer.offsetHeight;
                        var flowContainerScrollTop = _this.navMenuDOM ? _this.navMenuDOM.scrollTop : 0;
                        var expectedOffsetTop = offset.top - flowContainerScrollTop;
                        var parentHeight = offset.height;
                        var offsetBottom = expectedOffsetTop + flowContainerHeight;
                        var overBottom = getScreenHeight() - offsetBottom;
                        var finalOffsetTop = expectedOffsetTop;
                        var flowMenuOffsetTopPx = parentHeight == flowContainerHeight ? 0 : parentHeight;
                        if (overBottom < 0) {
                            /**
                             * 如果高度超过了底部
                             */
                            finalOffsetTop = expectedOffsetTop + overBottom;
                        }
                        flowMenuContainer.style.top = finalOffsetTop - flowMenuOffsetTopPx + "px";
                    }
                } }, _this.getNormalMenuChildren(activeItem.child)));
            var allSet = initDataList.map(function (item, idx) {
                if (!item)
                    return null;
                var _item = _this.menuItemFilter(item);
                var child = _item.child, title = _item.title, code = _item.code;
                var to = _this.wrapLink(_item);
                var isFold = !code || (child && child.length > 0);
                var key = code + title;
                var isHovering = activeIdx == idx;
                return isFold ? (React.createElement("div", { key: idx, onMouseEnter: function (e) {
                        delayExec.cancel();
                        var target = e.target;
                        if (e.currentTarget !== target)
                            return;
                        _this.setFlowMenu({
                            targetElem: target,
                            activeItem: _item,
                            idx: idx
                        });
                    }, onMouseLeave: function () {
                        _this.hideFlowMenu();
                    }, className: "fold" + (isHovering ? ' hover' : '') },
                    React.createElement(MenuItem, __assign({}, _item, { "$T": $T })))) : (_this.getMenuLinkerDOM(__assign(__assign({}, _item), { key: key,
                    to: to, onClick: onClickMenu, menuText: title })));
            });
            return (React.createElement("div", { className: "nav-menu-tree" },
                allSet,
                flowMenuDOM));
        };
        _this.menuItemFilter = function (item) {
            var menuMappers = _this.props.menuMappers;
            var child = menuMappers.child, code = menuMappers.code, title = menuMappers.title, _a = menuMappers.icon, icon = _a === void 0 ? '' : _a;
            return __assign(__assign({}, item), { child: item[child], code: item[code], title: item[title], icon: item[icon] });
        };
        _this.showSearch = function () {
        };
        _this.wrapLink = function (_a) {
            var path = _a.path, code = _a.code;
            return path ? code + "?" + path : code;
        };
        _this.changeMenuUIMode = function (isFlowMode) {
            _this.setState({
                flowMode: isFlowMode
            });
            storageHelper.set(_this.flowModeKey, isFlowMode ? '1' : '0');
        };
        _this.toggleFold = function (e, idx, isShow) {
            e.stopPropagation();
            var showMenuMapper = _this.state.showMenuMapper;
            var nextState = Object.assign({}, showMenuMapper);
            if (typeof isShow != 'undefined') {
                isShow ? (nextState[idx] = true) : delete nextState[idx];
            }
            else if (nextState.hasOwnProperty(idx)) {
                delete nextState[idx];
            }
            else {
                nextState[idx] = true;
            }
            Storage.setItem(MENU_ACTIVE_STORAGE, JSON.stringify(nextState));
            _this.setState({
                showMenuMapper: nextState
            });
        };
        _this.setFlowMenu = function (options) {
            var flowMenuConfig = _this.state.flowMenuConfig;
            var targetElem = options.targetElem, activeItem = options.activeItem, _a = options.isShow, isShow = _a === void 0 ? true : _a, idx = options.idx;
            var nextOffset = flowMenuConfig.offset;
            if (targetElem) {
                var offsetWidth = targetElem.offsetWidth, offsetHeight = targetElem.offsetHeight;
                nextOffset = {
                    top: getElementTop(targetElem),
                    left: getElementLeft(targetElem) + offsetWidth,
                    height: offsetHeight
                };
            }
            _this.setState({
                flowMenuConfig: {
                    offset: nextOffset,
                    activeIdx: idx,
                    activeItem: activeItem,
                    isShow: isShow
                }
            });
        };
        var showMenuMapper = Storage.getItem(MENU_ACTIVE_STORAGE) || '';
        try {
            showMenuMapper = JSON.parse(showMenuMapper);
        }
        catch (e) {
            showMenuMapper = {};
        }
        var storageMode = storageHelper.get(_this.flowModeKey);
        var _a = props.defaultFlowMode, defaultFlowMode = _a === void 0 ? false : _a, menuData = props.menuData;
        window.MENU_DATA = menuData;
        _this.state = {
            showMenuMapper: showMenuMapper,
            flowMenuConfig: {
                activeItem: {},
                activeIdx: '',
                isShow: false,
                offset: {
                    top: 0,
                    left: 0
                }
            },
            flowMode: storageMode ? (!!+storageMode) : defaultFlowMode
        };
        return _this;
    }
    NavMenu.prototype.componentDidMount = function () {
        Call(this.props.onDidMount, menuCodeMapper);
    };
    NavMenu.prototype.render = function () {
        var _this = this;
        var _a = this.props, menuData = _a.menuData, onClickMenu = _a.onClickMenu, onToggleNav = _a.onToggleNav, _b = _a.title, title = _b === void 0 ? 'UKE-Dashboard' : _b, 
        // username,
        // logout,
        $T = _a.$T, show = _a.show;
        var flowMode = this.state.flowMode;
        var menuTree = flowMode ? (this.getFlowModeDOM(menuData)) : (React.createElement("div", { className: "nav-menu-tree" }, this.getNormalMenuChildren(menuData)));
        var renderRes = (React.createElement("div", { className: "nav-menu-wrapper " + (show ? 'show' : 'collapse') },
            React.createElement("div", { ref: function (navMenuDOM) {
                    if (navMenuDOM)
                        _this.navMenuDOM = navMenuDOM;
                }, className: "nav-menu-response " + (flowMode ? 'flow-mode ' : 'tree-mode ') },
                React.createElement("div", { className: "menu-header" },
                    React.createElement("h4", { className: "title" }, title),
                    React.createElement("hr", null),
                    React.createElement("div", { className: "action-group" },
                        React.createElement(SearchBox, { ref: function (e) { _this._seatchBox = e; }, "$T": $T, onClickMenu: onClickMenu, onToggleNav: onToggleNav, codeMapper: menuCodeMapper, showMenu: show }),
                        React.createElement(ToolTip, { position: "top", title: $T('切换到') + $T(!flowMode ? '悬浮' : '传统') + $T('模式'), classNames: ['_action-btn'], className: "p10", onClick: function () { return _this.changeMenuUIMode(!flowMode); }, n: flowMode ? "bars" : "bolt" }),
                        React.createElement("span", { className: "flex" }),
                        React.createElement(ToolTip, { onClick: function () { return onToggleNav(!show); }, title: "" + $T(show ? "收起" : "展开") + $T('菜单') + "\uFF08" + $T('快捷键') + "\uFF1Aalt + alt\uFF09'", n: !show ? "greater-than" : "less-than" }))),
                menuTree)));
        return renderRes;
    };
    return NavMenu;
}(Component));
export default NavMenu;
